@@ -16,6 +16,11 @@ from collective.taghelper.utilities import get_ttn_subjects
 from collective.taghelper.utilities import get_ttn_subjects_remote
 from collective.taghelper.utilities import get_alchemy_subjects
 from collective.taghelper.utilities import get_alchemy_subjects_remote
+from collective.taghelper.utilities import get_zemanta_subjects
+from collective.taghelper.utilities import get_amplify_subjects
+from collective.taghelper.utilities import get_amplify_subjects_remote
+from collective.taghelper.utilities import get_evri_subjects
+
 from collective.taghelper.interfaces import ITagHelperSettingsSchema
 
 class IExtractedTermsView(Interface):
@@ -100,18 +105,24 @@ class ETSnippetView(BrowserView):
         self.request = request
         if self.context.portal_type == 'File':
             self.url = self.request.URL1 +'/filehtmlpreview_view'
-        elif hasattr(self.context, 'getRemoteUrl'):
+        if hasattr(self.context, 'getRemoteUrl'):
             if self.use_remote_url and self.context.getRemoteUrl():
                 self.url = self.context.getRemoteUrl()
             else:
                 self.url = self.request.URL1 +'?ajax_load=1'
+                self.use_remote_url = False
+        else:
+            self.use_remote_url = False
         if not self.url:
             self.url = self.request.URL1 +'?ajax_load=1'
         self.text = self._get_text()
 
     def _get_text(self):
         if hasattr(self.context, 'SearchableText'):
-            return self.context.SearchableText()
+            text = self.context.SearchableText().strip().lstrip(self.context.id).encode('utf-8', 'ignore')
+            text = text.lstrip().lstrip(self.context.Title().encode('utf-8', 'ignore')).encode('utf-8', 'ignore')
+            text = self.context.Title().encode('utf-8', 'ignore') + u'\n\n' + text
+            return text
         else:
             return ''
 
@@ -137,12 +148,24 @@ class ETSnippetView(BrowserView):
                 tags = get_yql_subjects_remote(self.url)
             else:
                  tags = get_yql_subjects(self.text)
-
+        elif sid=='openamplify':
+            if self.use_remote_url:
+                tags = get_amplify_subjects_remote(self.url)
+            else:
+                 tags = get_amplify_subjects(self.text)
+        elif sid=='evri':
+            if self.use_remote_url:
+                tags = get_evri_subjects(self.url)
+            else:
+                 tags = get_evri_subjects(self.url, self.text)
         elif sid=='opencalais':
             tags = get_calais_subjects(self.text, self.context.UID())
         elif sid=='sillc':
             text = self.context.Title() + '. ' + self.context.Description()
             tags = get_silcc_subjects(text)
+        elif sid =='zemanta':
+            tags = get_zemanta_subjects(self.text, self.context.Title())
+
         else:
             return []
         keywords = list(self.context.Subject())
@@ -172,6 +195,23 @@ class ETSnippetView(BrowserView):
             </a>"""
         elif sid=='sillc':
             t = ''
+        elif sid =='zemanta':
+            t= """<a href="http://developer.zemanta.com/API_terms_of_use/">
+            Terms of Use
+            <img src="http://www.zemanta.com/smedia/img/layout/logo.png" alt="Zemanta"/>
+            </a>
+             """
+        elif sid =='openamplify':
+            t= """<a href="http://openamplify.com/terms">
+            OpenAmplify Terms of Service </a>
+            <a href="http://www.openAmplify.com" >
+            <img src="http://openamplify.com/sites/default/files/logo.png" alt="openAmplify" />
+            </a>
+             """
+        elif sid =='evri':
+            t= """<a href=https://www.webservius.com/cons-help/legal/consumer-agreement.aspx?cobrand=Evri" >
+            Consumer Agreement </a>
+            """
         else:
             t = ''
         return t
